@@ -23,10 +23,7 @@
 
 #include <QObject>
 #include <QString>
-#include <QDBusArgument>
-#include <QDBusConnection>
 #include <QMovie>
-#include <QPixmap>
 #include <QSystemTrayIcon>
 #include <QWheelEvent>
 #include <QEventLoopLocker>
@@ -54,11 +51,11 @@ public:
     {
     }
 
-    bool event(QEvent *e) Q_DECL_OVERRIDE
+    bool event(QEvent *e) override
     {
         if (e->type() == QEvent::Wheel) {
             QWheelEvent *wheelEvent = static_cast<QWheelEvent *>(e);
-            emit wheel(wheelEvent->delta());
+            emit wheel(wheelEvent->angleDelta().y());
         }
 
         return false;
@@ -79,7 +76,13 @@ public:
 
         movie->setParent(this);
         movie->setCacheMode(QMovie::CacheAll);
-        connect(movie, SIGNAL(frameChanged(int)), this, SLOT(slotNewFrame()));
+        connect(movie, &QMovie::frameChanged, this, &KStatusNotifierLegacyIcon::slotNewFrame);
+    }
+
+    void setIconWithMask(QIcon &icon, bool isMask)
+    {
+        icon.setIsMask(isMask);
+        QSystemTrayIcon::setIcon(icon);
     }
 
 Q_SIGNALS:
@@ -155,6 +158,7 @@ public:
     QMenu *menu;
     QHash<QString, QAction *> actionCollection;
     QWidget *associatedWidget;
+    QPoint associatedWidgetPos;
     QAction *titleAction;
     org::kde::StatusNotifierWatcher *statusNotifierWatcher;
     org::freedesktop::Notifications *notificationsClient;
