@@ -21,10 +21,9 @@
 #include <QTimer>
 
 #include <QApplication>
-#include <QLabel>
 #include <QDebug>
-#include <QtDBus/QDBusConnection>
-#include <QtDBus/QDBusMessage>
+#include <QDBusConnection>
+#include <QDBusMessage>
 
 void notificationDBusCall(const QString &iconName, const QString &title, const QString &body, const QStringList &actions, bool persistent = false)
 {
@@ -40,7 +39,7 @@ void notificationDBusCall(const QString &iconName, const QString &title, const Q
 
     QStringList actionList;
     int actId = 0;
-    Q_FOREACH (const QString &actionName, actions) {
+    for (const QString &actionName : actions) {
         actId++;
         actionList.append(QString::number(actId));
         actionList.append(actionName);
@@ -75,7 +74,7 @@ int main(int argc, char *argv[])
 
     // wait a little before sending another notification
     QEventLoop a;
-    QTimer::singleShot(500, &a, SLOT(quit()));
+    QTimer::singleShot(500, &a, &QEventLoop::quit);
     a.exec();
 
     notificationDBusCall(QStringLiteral("kwalletmanager"),
@@ -83,7 +82,7 @@ int main(int argc, char *argv[])
                          QStringLiteral("Praesent odio ipsum, posuere a magna ac, egestas vehicula lectus"),
                          QStringList() << QStringLiteral("action1") << QStringLiteral("action2"));
 
-    QTimer::singleShot(1000, &a, SLOT(quit()));
+    QTimer::singleShot(1000, &a, &QEventLoop::quit);
     a.exec();
 
     notificationDBusCall(QStringLiteral("preferences-desktop-accessibility"),
